@@ -3,7 +3,7 @@ from .version import __version__
 from functools import lru_cache
 from glob import glob
 from os import environ, path
-from typing import Iterator, List, Optional, Type, Union
+from typing import Dict, Iterator, List, Optional, Type, Union
 from urllib.parse import urlparse, urlunparse
 
 import requests
@@ -87,6 +87,7 @@ TEMPLATES_URL = "{api_url}/templates"
 TEMPLATE_URL = "{api_url}/templates/{id}"
 TEMPLATE_DOWNLOAD_URL = "{api_url}/templates/{id}/download"
 
+METHODS = set(['get','post','patch'])
 
 class Session:
     def __init__(
@@ -132,6 +133,13 @@ class Session:
         self._get.cache_clear()
         return resp
 
+    def _patch(self, url: str, json_dict: dict) -> requests.Response:
+        resp = self._session.patch(url, json=json_dict)
+        if resp.status_code >= 400:
+            raise ValueError(resp.content)
+        self._get.cache_clear()
+        return resp
+
     def _delete(self, url: str) -> requests.Response:
         resp = self._session.delete(url)
         if resp.status_code >= 400:
@@ -649,3 +657,23 @@ class Session:
         if nav_block.links.default_draft:
             self._delete(nav_block.links.default_draft)
         return BlockVersion(**resp.json())
+
+    def simple_auth_call(self, method: str, url: str, body: Optional[Dict] = None):
+        """
+            Use the authenticated session to make a direct api call
+        """
+        if method not in METHODS:
+            raise ValueError(f'Unsupported method {method}')
+
+        if method == 'get':
+            return self._get(url)
+        elif method == 'post':
+            if body is not None:
+                return self._post(url, body)
+            else:
+                raise ValueError('Must post a body')
+        elif method == 'patch':
+            if body is not None:
+                return self._patch(url, body)
+            else:
+                raise ValueError('Must patch a body')
