@@ -1,16 +1,16 @@
-from curvenote.latex.schema.RaggedBottomOption import RaggedBottomSchemaOption
-from curvenote.latex.schema import (
+import os
+import logging
+import pkg_resources
+from .schema.RaggedBottomOption import RaggedBottomSchemaOption
+from .schema import (
     CalloutSchemaOption,
     CodeSchemaOption,
     HideLinksSchemaOption,
     SloppySchemaOption,
     StringSchemaOption,
 )
-import os
-import logging
-import pkg_resources
 from .utils.decorators import just_log_errors, log_and_raise_errors
-from .TemplateOptions import TemplateOptions
+from .templating.TemplateOptions import TemplateOptions
 from .schema.AsideSchemaOption import AsideSchemaOption
 from typing import Dict
 
