@@ -1,18 +1,20 @@
-from curvenote.models import BlockFormat
 import logging
 import os
+from jinja2.loaders import PackageLoader
 import yaml
 import pkg_resources
-from typing import Optional, Dict
-from enum import Enum
+from typing import Dict
 from zipfile import ZipFile
 from shutil import copyfile
-from .TemplateRenderer import TemplateRenderer
-from .TemplateOptions import TemplateOptions
+from distutils.dir_util import copy_tree
+from .templating.TemplateRenderer import TemplateRenderer
+from .templating.TemplateOptions import TemplateOptions
 from ..utils import download
 from ..client import Session
 from .DefBuilder import DefBuilder
 
+TEMPLATES_PATH = pkg_resources.resource_filename("curvenote", "latex/templates")
+DEFAULT_TEMPLATE_PATH = os.path.join(TEMPLATES_PATH, "default")
 
 class TemplateLoader:
     def __init__(self, target_folder: str):
@@ -38,7 +40,31 @@ class TemplateLoader:
 
         self.template_name = "default"
         self.renderer = TemplateRenderer()
-        self.options = TemplateOptions()
+        self.renderer.use_loader(PackageLoader("curvenote", os.path.join("latex", "templates", "default")))
+        self.options = TemplateOptions(DEFAULT_TEMPLATE_PATH)
+
+    def initialise_from_path(self, local_template_path: str):
+        logging.info("Using local template found at: %s", local_template_path)
+
+        abs_path = os.path.abspath(os.path.expanduser(local_template_path))
+
+        if not os.path.exists(abs_path):
+            raise ValueError('local template path does not exist')
+
+        if not os.path.isdir(abs_path):
+            raise ValueError('local template path must point to a folder')
+
+        try:
+            copy_tree(abs_path, self.target_folder)
+        except Exception as err:
+            logging.error("Could not copy local template from %s to %s", abs_path, self.target_folder)
+            logging.error(str(err))
+            raise err
+
+        self.template_name = os.path.basename(os.path.normpath(abs_path))
+        self.renderer = TemplateRenderer()
+        self.renderer.use_from_folder(self.target_folder)
+        self.options = TemplateOptions(self.target_folder)
 
     def initialise_from_template(self, session: Session, template_name: str):
         logging.info("Writing to target folder: %s", self.target_folder)
@@ -70,11 +96,16 @@ class TemplateLoader:
         self.options = TemplateOptions(self.target_folder)
 
     def set_user_options_from_yml(self, user_options_path: str):
+        if self.options is None:
+            raise ValueError('TemplateLoader not initialized')
+
         with open(user_options_path, "r") as file:
-            self.options.parse_user_optons(yaml.load(file, Loader=yaml.FullLoader))
+            self.options.set_user_options(yaml.load(file, Loader=yaml.FullLoader))
 
     def set_user_options(self, user_options: Dict):
-        self.options.parse_user_option(user_options)
+        if self.options is None:
+            raise ValueError('TemplateLoader not initialized')
+        self.options.set_user_options(user_options)
 
     def build_defs(self):
         """
@@ -89,7 +120,7 @@ class TemplateLoader:
                 using the default
             1.2 log any package dependencied in the package listing
         """
-        if self.template_name is None:
+        if self.template_name is None or self.options is None:
             raise ValueError("TemplateLoader has not been initialized")
         def_builder = DefBuilder()
         def_builder.build(self.options, self.target_folder)
