@@ -2,5 +2,5 @@ from .LatexArticle import LatexArticle
 from .LatexProjectBuilder import LatexProjectBuilder
 from .LatexBlockVersion import LatexBlockVersion
 from .TemplateLoader import TemplateLoader
-from .TemplateOptions import TemplateOptions
-from .TemplateRenderer import TemplateRenderer
+from .templating.TemplateOptions import TemplateOptions
+from .templating.TemplateRenderer import TemplateRenderer
