@@ -1,7 +1,8 @@
 from .SchemaOptionDefs import CustomTemplateDefs, SchemaOptionDefs
 from typing import Dict, Optional, Union
 
-class BooleanSchemaOption():
+
+class BooleanSchemaOption:
     def __init__(self):
         self.when_true: Union[SchemaOptionDefs, CustomTemplateDefs, None] = None
         self.when_false: Union[SchemaOptionDefs, CustomTemplateDefs, None] = None
@@ -16,7 +17,9 @@ class BooleanSchemaOption():
     def set_default(self, flag: bool):
         self.default = flag
 
-    def get(self, flag: Optional[bool] = None) -> Union[SchemaOptionDefs, CustomTemplateDefs]:
+    def get(
+        self, flag: Optional[bool] = None
+    ) -> Union[SchemaOptionDefs, CustomTemplateDefs]:
         if flag is None and self.default is None:
             raise ValueError("No default option set")
         real_flag = self.default if flag is None else flag
