@@ -2,7 +2,9 @@ import logging
 import re
 import time
 from collections import namedtuple
-from typing import List, NamedTuple, Optional, Union
+from typing import List, NamedTuple, Optional, Type, Union
+
+from pydantic.main import BaseModel
 
 from ...client import Session
 from ...models import Block, BlockFormat, BlockVersion
@@ -13,9 +15,6 @@ from typing import NamedTuple
 from ...models import BlockVersion
 
 
-logger = logging.getLogger()
-
-
 class LocalMarker(NamedTuple):
     marker: str
     local_path: str
@@ -24,7 +23,7 @@ class LocalMarker(NamedTuple):
 
 
 # TODO move to session - easier to mock
-def get_model(session, url, model=BlockVersion):
+def get_model(session: Session, url: str, model: Type[BaseModel] = BlockVersion):
     block = session.get_model(url, model)
     if not block:
         raise ValueError(f"Could not fetch the block {url}")
