@@ -1,7 +1,7 @@
 import re
 import logging
 from typing import List
-from curvenote.models import Block
+from curvenote.models import Block, BlockVersion
 from .parse_cite_tag_from_bibtex import parse_cite_tag_from_bibtex
 from .links import block_hash_to_api_url, oxa_path_to_api_url, unpin_oxa_path
 from .index import (
@@ -10,13 +10,35 @@ from .index import (
 )
 from ...client import Session
 from .regex import (
+    BLOCK_REGEX,
     INLINE_CITATION_BLOCK_REGEX,
     INLINE_CITATION_OXA_REGEX,
-    UNPIN_OXA_REGEX,
+    OXA_REGEX,
+    UNPINNED_BLOCK_REGEX_ENDLINE,
+    UNPINNED_BLOCK_REGEX_INLINE,
+    UNPINNED_OXA_REGEX_ENDLINE,
+    UNPINNED_OXA_REGEX_INLINE,
 )
 from .run_regex_matchers import run_regex_matchers
 
 
+def split_remote_paths(remote_path: str) -> List[str]:
+    """Splits a remote path into a list of block_paths or oxa_paths"""
+    matches = run_regex_matchers([
+            OXA_REGEX, UNPINNED_OXA_REGEX_ENDLINE,
+            UNPINNED_OXA_REGEX_INLINE, BLOCK_REGEX,
+            UNPINNED_BLOCK_REGEX_ENDLINE, UNPINNED_BLOCK_REGEX_INLINE
+            ], remote_path)
+
+    if len(matches) == 0:
+        return [remote_path]
+
+    if len(matches) > 1:
+        logging.info("Found group of %s paths, splitting...", len(matches))
+
+    return [m[0] for m in matches]
+
+
 def localize_references_from_content_block(
     session: Session, reference_list: List[LocalMarker], content: str
 ):
@@ -32,7 +54,12 @@ def localize_references_from_content_block(
     matches = run_regex_matchers(
         [INLINE_CITATION_BLOCK_REGEX, INLINE_CITATION_OXA_REGEX], content
     )
-    remote_paths = [m[1] for m in matches]
+
+    # citep blocks can contain multiple citations, so we need to iterate over
+    # the list of matches, check each one and split them
+    remote_paths: List[str] = []
+    for match in matches:
+        remote_paths += split_remote_paths(match[1])
 
     for remote_path in remote_paths:
         logging.info("processing remote path: %s", remote_path)
@@ -56,14 +83,14 @@ def localize_references_from_content_block(
             # get latest version
             version_url = f"{url}/versions/{block.latest_version}?format=bibtex"
             logging.info("fetching reference version %s", version_url)
-            version = get_model(session, version_url)
+            version = get_model(session, version_url, BlockVersion)
             logging.info("got reference version")
 
             # update the list
-            marker, plain_tag = parse_cite_tag_from_bibtex(version.content)
-            bibtex_content = version.content.replace(plain_tag, marker)
+            bibtex_content: str = version.content
+            _, plain_tag = parse_cite_tag_from_bibtex(bibtex_content)
 
-            reference_item = LocalMarker(marker, remote_path, plain_tag, bibtex_content)
+            reference_item = LocalMarker(plain_tag, remote_path, plain_tag, bibtex_content)
             reference_list.append(reference_item)
             existing_reference = reference_item
             logging.info("using new reference %s", existing_reference.marker)
