@@ -2,7 +2,7 @@ import os
 import re
 import requests
 from sre_constants import GROUPREF
-from typing import Dict, Union
+from typing import Dict, Union, cast
 from urllib.parse import parse_qs, urlencode, urlparse, urlunparse
 from .models import BlockID, PathSpec, VersionID, SrcID
 from pydantic import AnyHttpUrl
@@ -123,3 +123,10 @@ def download(url, save_path, chunk_size=128):
     with open(save_path, "wb") as file:
         for chunk in resp.iter_content(chunk_size=chunk_size):
             file.write(chunk)
+
+def id_to_api_url(base: str, the_id: Union[BlockID,VersionID,SrcID]):
+    if 'version' in the_id.__dict__:
+        version_id = cast(VersionID, the_id)
+        return f"{base}/blocks/{version_id.project}/{version_id.block}/versions/{version_id.version}"
+    else:
+        return f"{base}/blocks/{the_id.project}/{the_id.block}"
